#ifndef NT2_INCLUDE_FUNCTIONS_NORM_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NORM_HPP_INCLUDED

#include <nt2/linalg/include/functions/norm.hpp>

#endif
